#   Copyright 2007,2008,2009,2011 Everyblock LLC, OpenPlans, and contributors
#
#   This file is part of ebpub
#
#   ebpub is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   ebpub is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with ebpub.  If not, see <http://www.gnu.org/licenses/>.
#

# These might end up in settings eventually, but for now it's fine to
# hardcode them.

BLOCK_RADIUS_CHOICES = {'1': .0015, '3': .0035, '8': .007} # number of blocks -> number of geographic degrees ... should this vary with latitude? oh well.
BLOCK_RADIUS_COOKIE_NAME = 'radius'
BLOCK_RADIUS_DEFAULT = '8'
HIDE_ADS_COOKIE_NAME = 'h'

# How far from a block center various model geometries can be,
# and still be considered on that block.
BLOCK_FUZZY_DISTANCE_METERS = 15
